from uselessutilities import *

def test_addition():
    assert ter(10) + ter(10) == ter(20)
    assert quat(10) + quat(10) == quat(20)
    assert quin(10) + quin(10) == quin(20)
    assert sen(10) + sen(10) == sen(20)
    assert sept(10) + sept(10) == sept(20)
    assert non(10) + non(10) == non(20)

    assert ter(10) + quat(10) == ter(20)
    assert ter(10) + quin(10) == ter(20)
    assert ter(10) + sen(10) == ter(20)
    assert ter(10) + sept(10) == ter(20)
    assert ter(10) + non(10) == ter(20)

    assert quat(10) + ter(10) == quat(20)
    assert quat(10) + quin(10) == quat(20)
    assert quat(10) + sen(10) == quat(20)
    assert quat(10) + sept(10) == quat(20)
    assert quat(10) + non(10) == quat(20)

    assert quin(10) + ter(10) == quin(20)
    assert quin(10) + quat(10) == quin(20)
    assert quin(10) + sen(10) == quin(20)
    assert quin(10) + sept(10) == quin(20)
    assert quin(10) + non(10) == quin(20)

    assert sen(10) + ter(10) == sen(20)
    assert sen(10) + quat(10) == sen(20)
    assert sen(10) + quin(10) == sen(20)
    assert sen(10) + sept(10) == sen(20)
    assert sen(10) + non(10) == sen(20)

    assert sept(10) + ter(10) == sept(20)
    assert sept(10) + quat(10) == sept(20)
    assert sept(10) + quin(10) == sept(20)
    assert sept(10) + sen(10) == sept(20)
    assert non(10) + ter(10) == non(20)

    assert non(10) + ter(10) == non(20)
    assert non(10) + quat(10) == non(20)
    assert non(10) + quin(10) == non(20)
    assert non(10) + sen(10) == non(20)
    assert non(10) + sept(10) == non(20)

    assert ter(10) + 10 == ter(20)
    assert quat(10) + 10 == quat(20)
    assert quin(10) + 10 == quin(20)
    assert sen(10) + 10 == sen(20)
    assert sept(10) + 10 == sept(20)
    assert non(10) + 10 == non(20)

def test_subtraction():
    assert ter(10) - ter(10) == ter(0)
    assert quat(10) - quat(10) == quat(0)
    assert quin(10) - quin(10) == quin(0)
    assert sen(10) - sen(10) == sen(0)
    assert sept(10) - sept(10) == sept(0)
    assert non(10) - non(10) == non(0)

    assert ter(10) - quat(10) == ter(0)
    assert ter(10) - quin(10) == ter(0)
    assert ter(10) - sen(10) == ter(0)
    assert ter(10) - sept(10) == ter(0)
    assert ter(10) - non(10) == ter(0)

    assert quat(10) - ter(10) == quat(0)
    assert quat(10) - quin(10) == quat(0)
    assert quat(10) - sen(10) == quat(0)
    assert quat(10) - sept(10) == quat(0)
    assert quat(10) - non(10) == quat(0)

    assert quin(10) - ter(10) == quin(0)
    assert quin(10) - quat(10) == quin(0)
    assert quin(10) - sen(10) == quin(0)
    assert quin(10) - sept(10) == quin(0)
    assert quin(10) - non(10) == quin(0)

    assert sen(10) - ter(10) == sen(0)
    assert sen(10) - quat(10) == sen(0)
    assert sen(10) - quin(10) == sen(0)
    assert sen(10) - sept(10) == sen(0)
    assert sen(10) - non(10) == sen(0)

    assert sept(10) - ter(10) == sept(0)
    assert sept(10) - quat(10) == sept(0)
    assert sept(10) - quin(10) == sept(0)
    assert sept(10) - sen(10) == sept(0)
    assert sept(10) - non(10) == sept(0)

    assert non(10) - ter(10) == non(0)
    assert non(10) - quat(10) == non(0)
    assert non(10) - quin(10) == non(0)
    assert non(10) - sen(10) == non(0)
    assert non(10) - sept(10) == non(0)

    assert sen(10) - 10 == sen(0)
    assert quat(10) - 10 == quat(0)
    assert quin(10) - 10 == quin(0)
    assert sen(10) - 10 == sen(0)
    assert sept(10) - 10 == sept(0)
    assert non(10) - 10 == non(0)

def test_multiplication():
    assert ter(10) * ter(10) == ter(100)
    assert quat(10) * quat(10) == quat(100)
    assert quin(10) * quin(10) == quin(100)
    assert sen(10) * sen(10) == sen(100)
    assert sept(10) * sept(10) == sept(100)
    assert non(10) * non(10) == non(100)

    assert ter(10) * quat(10) == ter(100)
    assert ter(10) * quin(10) == ter(100)
    assert ter(10) * sen(10) == ter(100)
    assert ter(10) * sept(10) == ter(100)
    assert ter(10) * non(10) == ter(100)

    assert quat(10) * ter(10) == quat(100)
    assert quat(10) * quin(10) == quat(100)
    assert quat(10) * sen(10) == quat(100)
    assert quat(10) * sept(10) == quat(100)
    assert quat(10) * non(10) == quat(100)

    assert quin(10) * ter(10) == quin(100)
    assert quin(10) * quat(10) == quin(100)
    assert quin(10) * sen(10) == quin(100)
    assert quin(10) * sept(10) == quin(100)
    assert quin(10) * non(10) == quin(100)

    assert sen(10) * ter(10) == sen(100)
    assert sen(10) * quat(10) == sen(100)
    assert sen(10) * quin(10) == sen(100)
    assert sen(10) * sept(10) == sen(100)
    assert sen(10) * non(10) == sen(100)

    assert sept(10) * ter(10) == sept(100)
    assert sept(10) * quat(10) == sept(100)
    assert sept(10) * quin(10) == sept(100)
    assert sept(10) * sen(10) == sept(100)
    assert sept(10) * non(10) == sept(100)

    assert non(10) * ter(10) == non(100)
    assert non(10) * quat(10) == non(100)
    assert non(10) * quin(10) == non(100)
    assert non(10) * sen(10) == non(100)
    assert non(10) * sept(10) == non(100)

    assert ter(10) * 10 == ter(100)
    assert quat(10) * 10 == quat(100)
    assert quin(10) * 10 == quin(100)
    assert sen(10) * 10 == sen(100)
    assert sept(10) * 10 == sept(100)
    assert non(10) * 10 == non(100)

def test_division():
    assert ter(10) / ter(10) == ter(1)
    assert quat(10) / quat(10) == quat(1)
    assert quin(10) / quin(10) == quin(1)
    assert sen(10) / sen(10) == sen(1)
    assert sept(10) / sept(10) == sept(1)
    assert non(10) / non(10) == non(1)

    assert ter(10) / quat(10) == ter(1)
    assert ter(10) / quin(10) == ter(1)
    assert ter(10) / sen(10) == ter(1)
    assert ter(10) / sept(10) == ter(1)
    assert ter(10) / non(10) == ter(1)

    assert quat(10) / ter(10) == quat(1)
    assert quat(10) / quin(10) == quat(1)
    assert quat(10) / sen(10) == quat(1)
    assert quat(10) / sept(10) == quat(1)
    assert quat(10) / non(10) == quat(1)

    assert quin(10) / ter(10) == quin(1)
    assert quin(10) / quat(10) == quin(1)
    assert quin(10) / sen(10) == quin(1)
    assert quin(10) / sept(10) == quin(1)
    assert quin(10) / non(10) == quin(1)

    assert sen(10) / ter(10) == sen(1)
    assert sen(10) / quat(10) == sen(1)
    assert sen(10) / quin(10) == sen(1)
    assert sen(10) / sept(10) == sen(1)
    assert sen(10) / non(10) == sen(1)

    assert sept(10) / ter(10) == sept(1)
    assert sept(10) / quat(10) == sept(1)
    assert sept(10) / quin(10) == sept(1)
    assert sept(10) / sen(10) == sept(1)
    assert sept(10) / non(10) == sept(1)

    assert non(10) / ter(10) == non(1)
    assert non(10) / quat(10) == non(1)
    assert non(10) / quin(10) == non(1)
    assert non(10) / sen(10) == non(1)
    assert non(10) / sept(10) == non(1)

    assert ter(10) / 10 == ter(1)
    assert quat(10) / 10 == quat(1)
    assert quin(10) / 10 == quin(1)
    assert sen(10) / 10 == sen(1)
    assert sept(10) / 10 == sept(1)
    assert non(10) / 10 == non(1)

def test_modulo():
    assert ter(10) % ter(10) == ter(0)
    assert quat(10) % quat(10) == quat(0)
    assert quin(10) % quin(10) == quin(0)
    assert sen(10) % sen(10) == sen(0)
    assert sept(10) % sept(10) == sept(0)
    assert non(10) % non(10) == non(0)

    assert ter(10) % quat(10) == ter(0)
    assert ter(10) % quin(10) == ter(0)
    assert ter(10) % sen(10) == ter(0)
    assert ter(10) % sept(10) == ter(0)
    assert ter(10) % non(10) == ter(0)

    assert quat(10) % ter(10) == quat(0)
    assert quat(10) % quin(10) == quat(0)
    assert quat(10) % sen(10) == quat(0)
    assert quat(10) % sept(10) == quat(0)
    assert quat(10) % non(10) == quat(0)

    assert quin(10) % ter(10) == quin(0)
    assert quin(10) % quat(10) == quin(0)
    assert quin(10) % sen(10) == quin(0)
    assert quin(10) % sept(10) == quin(0)
    assert quin(10) % non(10) == quin(0)

    assert sen(10) % ter(10) == sen(0)
    assert sen(10) % quat(10) == sen(0)
    assert sen(10) % quin(10) == sen(0)
    assert sen(10) % sept(10) == sen(0)
    assert sen(10) % non(10) == sen(0)

    assert sept(10) % ter(10) == sept(0)
    assert sept(10) % quat(10) == sept(0)
    assert sept(10) % quin(10) == sept(0)
    assert sept(10) % sen(10) == sept(0)
    assert sept(10) % non(10) == sept(0)

    assert non(10) % ter(10) == non(0)
    assert non(10) % quat(10) == non(0)
    assert non(10) % quin(10) == non(0)
    assert non(10) % sen(10) == non(0)
    assert non(10) % sept(10) == non(0)

    assert ter(10) % 10 == ter(0)
    assert quat(10) % 10 == quat(0)
    assert quin(10) % 10 == quin(0)
    assert sen(10) % 10 == sen(0)
    assert sept(10) % 10 == sept(0)
    assert non(10) % 10 == non(0)


class quinary:
    def __init__(self, tval, isnegative=False):
        self.quinval = tval
        self.intval = int(tval, 5)
        self.length = len(tval)
        self.length = len(tval)
        self.isnegative = isnegative
        self.digits = list(str(tval))
        self.true_intval = self.intval if not self.isnegative else -self.intval

    def __str__(self):
        return str("0Q" + self.quinval)
    
    def __int__(self):
        return self.true_intval
    
    def __float__(self):
        return float(self.true_intval)
    
    def __eq__(self, other):
        if isinstance(other, quinary):
            return self.true_intval == other.true_intval
        elif hasattr(other, 'true_intval'):
            return self.true_intval == other.true_intval
        else:
            return self.true_intval == int(other)

    def __add__(self, other):
        if isinstance(other, quinary):
            return quin(self.true_intval + other.true_intval) # handle self-to-self adding
        elif hasattr(other, 'true_intval'):
            return quin(self.true_intval + other.true_intval) # handle mixed adding
        elif isinstance(other, float):
            return quin(self.true_intval + other) # handle floats
        else:
            return quin(self.true_intval + int(other)) # handle non-uselessutilities adding

    def __sub__(self, other):
        if isinstance(other, quinary):
            return quin(self.true_intval - other.true_intval) # handle self-to-self subtracting
        elif hasattr(other, 'true_intval'):
            return quin(self.true_intval - other.true_intval) # handle mixed subtracting
        elif isinstance(other, float):
            return quin(self.true_intval - other) # handle floats
        else:
            return quin(self.true_intval - int(other)) # handle non-uselessutilities subtracting

    def __mul__(self, other):
        if isinstance(other, quinary):
            return quin(self.true_intval * other.true_intval) # handle self-to-self multiplying
        elif hasattr(other, 'true_intval'):
            return quin(self.true_intval * other.true_intval) # handle mixed multiplying
        elif isinstance(other, float):
            return quin(self.true_intval * other) # handle floats
        else:
            return quin(self.true_intval * int(other)) # handle non-uselessutilities multiplying

    def __truediv__(self, other):
        if isinstance(other, quinary):
            return quin(int(self.true_intval) // other.true_intval) # handle self-to-self dividing
        elif hasattr(other, 'true_intval'):
            return quin(int(self.true_intval) // other.true_intval) # handle mixed dividing
        elif isinstance(other, float):
            return quin(int(self.true_intval) // other) # handle floats
        else:
            return quin(int(self.true_intval) // int(other)) # handle non-uselessutilities dividing

    def __mod__(self, other):
        if isinstance(other, quinary):
            return quin(self.true_intval % other.true_intval) # handle self-to-self modulo
        elif hasattr(other, 'true_intval'):
            return quin(self.true_intval % other.true_intval) # handle mixed modulo
        elif isinstance(other, float):
            return quin(self.true_intval % other) # handle floats
        else:
            return quin(self.true_intval % int(other)) # handle non-uselessutilities modulo

def quin(n):
    neg = False
    if n < 0:
        neg = True
        n = abs(n)
    if n == 0:
        return '0'
    nums = []
    while n:
        n, r = divmod(n, 5)
        nums.append(str(r))
    out = ''.join(reversed(nums))
    t = quinary(out, isnegative=neg)
    return t


import argparse


def main(args=None):
    parser = argparse.ArgumentParser(description='Useless utilities')
    parser.add_argument('-v', '--version', action='version', version='1.1.5')
    args = parser.parse_args()


from uselessutilities import ter, quat, quin, sen, sept, non

def test_ter_basic():
    t = ter(10)
    assert str(t) == "0t101"
    assert int(t) == 10
    assert float(t) == 10.0

def test_quat_basic():
    q = quat(10)
    assert str(q) == "0q22"
    assert int(q) == 10
    assert float(q) == 10.0

def test_quin_basic():
    Q = quin(10)
    assert str(Q) == "0Q20"
    assert int(Q) == 10
    assert float(Q) == 10.0

def test_sen_basic():
    s = sen(10)
    assert str(s) == "0s14"
    assert int(s) == 10
    assert float(s) == 10.0

def test_sept_basic():
    S = sept(10)
    assert str(S) == "0S13"
    assert int(S) == 10
    assert float(S) == 10.0

def test_non_basic():
    n = non(10)
    assert str(n) == "0n11"
    assert int(n) == 10
    assert float(n) == 10.0


from .ternary import ter
from .quaternary import quat
from .quinary import quin
from .senary import sen
from .septenary import sept
from .nonary import non

__all__ = ["ter", "quat", "quin", "sen", "sept", "non"]